@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,8 +30,10 @@ public:
     explicit OperaAddressBook(const QString &filename, ImportWizard *parent);
     ~OperaAddressBook();
 
+    void importAddressBook();
 private:
     void appendContact(KContacts::Addressee *contact);
+    QString mFileName;
 };
 
 #endif // OPERAADDRESSBOOK_H
